Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2300)

Unified Diff: chrome/browser/chromeos/accessibility_util.cc

Issue 8198007: Remove PrefService::ScheduleSavePersistentPrefs and SavePersistentPrefs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix chromeos Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/accessibility_util.cc
diff --git a/chrome/browser/chromeos/accessibility_util.cc b/chrome/browser/chromeos/accessibility_util.cc
index b487e78e8bcab31a63219b443dc3289ddb3b80e6..67d1522c8f8bf569c9b9d59b75a90ce6bc3e906b 100644
--- a/chrome/browser/chromeos/accessibility_util.cc
+++ b/chrome/browser/chromeos/accessibility_util.cc
@@ -93,11 +93,10 @@ void EnableAccessibility(bool enabled, WebUI* login_web_ui) {
g_browser_process->local_state()->SetBoolean(
prefs::kAccessibilityEnabled, enabled);
- // Explicitly call SavePersistentPrefs instead of ScheduleSavePersistentPrefs
- // so that this change gets written immediately, in case the user shuts
- // down right now. TODO(dmazzoni) switch this back to
- // ScheduleSavePersistentPrefs once http://crosbug.com/19491 is fixed.
- g_browser_process->local_state()->SavePersistentPrefs();
+ // Explicitly call CommitPendingWrite so that this change gets written
+ // immediately, in case the user shuts down right now.
+ // TODO(dmazzoni) remove once http://crosbug.com/19491 is fixed.
Mattias Nissler (ping if slow) 2011/10/12 09:23:39 That bug is closed. Remove? Probably better not to
Bernhard Bauer 2011/10/12 11:02:05 OK. Dominic, can you take a look? :-D
+ g_browser_process->local_state()->CommitPendingWrite();
ExtensionAccessibilityEventRouter::GetInstance()->
SetAccessibilityEnabled(enabled);

Powered by Google App Engine
This is Rietveld 408576698